<?php
// $Id: pninit.php,v 1.8 2003/05/15 15:55:30 garubi Exp $
// ----------------------------------------------------------------------
// POST-NUKE Content Management System
// Copyright (C) 2001 by the PostNuke Development Team.
// http://www.postnuke.com/
// ----------------------------------------------------------------------
// Based on:
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Original Author of file: Stefano Garuti
// Purpose of file:  Initialisation functions for module event
// ----------------------------------------------------------------------

/**
 * initialise the event module
 */

function event_init()
{
    // Set up an initial value for a module variable.  Note that all module
    // variables should be initialised with some value in this way rather
    // than just left blank, this helps the user-side code and means that
    // there doesn't need to be a check to see if the variable is set in
    // the rest of the code as it always will be
    pnModSetVar('event', 'itemsperpage', 6);
	
	// event Submission by users:
	// the module var 'enable_submit' switch on or off this feature
	pnModSetVar('event', 'enable_submit', 1);

	pnModSetVar('event', 'email', pnConfigGetVar('adminmail'));
	
    // Get database information
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // Create tables
    $eventtable = $pntable['conc'];
    $eventcolumn = &$pntable['conc_column'];
    $sql = "CREATE TABLE $eventtable (
			$eventcolumn[dc_id] smallint(3) unsigned zerofill NOT NULL auto_increment,
  			$eventcolumn[dc_paese] varchar(50) NOT NULL default '',
  			$eventcolumn[dc_prov] char(2) NOT NULL default '',
  			$eventcolumn[dc_stato] varchar(10) NOT NULL default 'It',
  			$eventcolumn[dc_locale] varchar(50) NOT NULL default '',
  			$eventcolumn[dc_note] varchar(225) NOT NULL default '',
  			$eventcolumn[dc_infomailnome1] varchar(100) NOT NULL default '0',
  			$eventcolumn[dc_infomailaddr1] varchar(100) NOT NULL default '',
  			$eventcolumn[dc_infotel1] varchar(15) NOT NULL default '',
  			$eventcolumn[dc_infotel2] varchar(15) NOT NULL default '',
  			$eventcolumn[dc_url_locale] varchar(125) NOT NULL default '',
  			$eventcolumn[dc_indirizzo_locale] varchar(125) NOT NULL default '0',
  			$eventcolumn[dc_n_comm] tinyint(4) NOT NULL default '0',
  			$eventcolumn[dc_data] date NOT NULL default '0000-00-00',
  			$eventcolumn[dc_conf] tinyint(1) unsigned zerofill NOT NULL default '0',
  			$eventcolumn[dc_user] int(11) NOT NULL default '0',
  			$eventcolumn[dc_data_modif] datetime NOT NULL default '0000-00-00 00:00:00',
  			$eventcolumn[dc_category] tinyint(1) unsigned zerofill NOT NULL default '0',
  			$eventcolumn[dc_lang] varchar(30) NOT NULL default '',
  			$eventcolumn[dc_infotelnome1] varchar(80) NOT NULL default '',
  			$eventcolumn[dc_infotelnome2] varchar(80) NOT NULL default '',
				$eventcolumn[dc_approved] tinyint(1) unsigned zerofill DEFAULT '1' NOT NULL,
  			$eventcolumn[dc_submitter] int(11) NOT NULL default '0',
  			PRIMARY KEY  (dc_id),
			UNIQUE KEY $eventcolumn[dc_id] (dc_id)
			);";


// DEBUG
//echo '<pre>';
// $dbconn->debug = true;
 $dbconn->Execute($sql);
// echo '</pre>';


    // Check database result
    if ($dbconn->ErrorNo() != 0) {
        // Report failed initialisation attempt
        pnSessionSetVar('errormsg', _CREATETABLEFAILED);
		return false;
    }

    // Initialisation successful
    return true;
}

/**
 * upgrade the event module from an old version
 * This function can be called multiple times
 */
function event_upgrade($oldversion)
{
            list($dbconn) = pnDBGetConn();
            $pntable = pnDBGetTables();

            $eventtable = $pntable['event'];

	   // Upgrade dependent on old version number
    switch($oldversion) {
        case 0.1:
        case 0.2:
				case 0.3:
				case 0.4:
						 // event Submission by users:
						 // the module var 'enable_submit' switch on or off this feature
	     			 pnModSetVar('event', 'enable_submit', 0);	

                     // the module var 'email' keep the info to where send event's submission notification
                     pnModSetVar('event', 'email', pnConfigGetVar('adminmail'));

						 // we add 2 columns to the pnevent table to track the approvation
						 
						 // Get database information
						 list($dbconn) = pnDBGetConn();
    				 $pntable = pnDBGetTables();
						 
						 // Modify table: add a field to check if the event is approved
    				 $eventtable = $pntable['conc'];
    				 $eventcolumn = &$pntable['conc_column'];
						 $sql= "ALTER TABLE $eventtable 
						 			  ADD $eventcolumn[dc_approved] tinyint(1) unsigned zerofill DEFAULT '1' NOT NULL,
						   			ADD $eventcolumn[dc_submitter] int(11) NOT NULL default '0'"; 
						 // DEBUG
						 //echo '<pre>';
						 //$dbconn->debug = true;
						 $dbconn->Execute($sql);
						//	 echo '</pre>';
            
						
						// At the end of the successful completion of this function we
            // recurse the upgrade to handle any other upgrades that need
            // to be done.  This allows us to upgrade from any version to
            // the current version with ease
            return event_upgrade(0.5);
    }

    // Update successful
    return true;
}


/**
 * delete the event module
 */
function event_delete()
{

    // Get database information
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // Delete tables
    $sql = "DROP TABLE $pntable[conc]";
   // DEBUG
    //echo '<pre>';
    //$dbconn->debug = true;
    $dbconn->Execute($sql);
    //echo '</pre>';
    // Check database result
    if ($dbconn->ErrorNo() != 0) {
        // Report failed deletion attempt
        pnSessionSetVar('errormsg', _DELETETABLEFAILED);
		return false;
    }

    // Delete any module variables
    pnModDelVar('event', 'itemsperpage');
  	pnModDelVar('event', 'enable_submit');
    pnModDelVar('event', 'email');

    // Deletion successful
    return true;
}
?>
